@@ -17,16 +17,19 @@ Usage:
         timeout=1
     )
 
-    ser.write(dlt645.get_addr())
-
-    frame = dlt645.read_frame(dlt645.iogen(ser))
-    station_addr = frame.addr
+    station_addr = dlt645.get_addr(ser)
 
+    # requesting active energy
     frame = dlt645.Frame(station_addr)
     frame.data = "00000000"
-    framedata = dlt645.read_frame(serialgen(ser))
+    ser.write(frame.dump())
+    framedata = dlt645.read_frame(dlt645.iogen(ser))
+    # the data will be the full payload (energy valu and data identification)
     print(framedata.data)
 
+    # shorthand function to directly get the active energy value
+    dlt645.get_active_energy(station_addr, ser)
+
 """
 from .__meta__ import __version__  # noqa: F401
 from .constants import (
@@ -80,16 +83,19 @@ def read_frame(readgen):
             return frame
 
 
-def write_frame(frame, awaken=True):
+def write_frame(flo, frame, awaken=True):
     """Write a frame to byte form to be written on a data line
 
+    :param flo: a file-like object instance
     :param dlt645.Frame frame: a :class:`Frame` instance
     :param bool awaken: whether to prefix the message with wake up bytes
     """
     if awaken is True:
-        return 4 * b_awaken + frame.dump()
+        payload = 4 * b_awaken + frame.dump()
     else:
-        return frame.dump()
+        payload = frame.dump()
+
+    flo.write(payload)
 
 
 class Frame:
@@ -187,11 +193,6 @@ class Frame:
         return self.checksum == cs
 
 
-def get_addr():
-    """Return a byte-like payload to request an address from an unknown station"""
-    return b"\xfe\xfe\xfe\xfe\x68\xaa\xaa\xaa\xaa\xaa\xaa\x68\x13\x00\xdf\x16"
-
-
 def checksum(data):
     """Return the checksum of a byte-like object
 
@@ -287,3 +288,47 @@ def dump_data(data):
     bdata = bytearray([int(data[i : i + 2], 16) + 0x33 for i in range(0, len(data), 2)])
     bdata.reverse()
     return bdata
+
+
+def get_addr(flo, r_flo=None):
+    """Utility function to read a station's address, returns the address.
+
+    :param flo: a file-like object instance for write
+    :param r_flo: a file-like object instance for read
+    """
+    if r_flo is None:
+        r_flo = flo
+
+    # request address using broadcast target address
+    payload = b"\xfe\xfe\xfe\xfe\x68\xaa\xaa\xaa\xaa\xaa\xaa\x68\x13\x00\xdf\x16"
+    flo.write(payload)
+
+    resp = read_frame(iogen(r_flo))
+    return resp.addr
+
+
+def get_active_energy(addr, flo, r_flo=None):
+    """Utility function to directly read active energy field, returns the
+    energy value in kWh.
+
+    A file-like object is required for the communication, if 'r_flo' is
+    ``None`` then 'flo' will be used for both read and write. This is useful
+    when using a ``socketserver.StreamRequestHandler`` that provides different
+    file-like objects for read and write.
+
+    :param str addr: a station address
+    :param flo: a file-like object instance for write
+    :param r_flo: a file-like object instance for read
+    """
+    if r_flo is None:
+        r_flo = flo
+
+    frame = Frame(addr)
+    # Data identification for active energy
+    frame.data = "00000000"
+    write_frame(flo, frame)
+
+    resp = read_frame(iogen(r_flo))
+    # test the data identification
+    if resp.data[-8:] == "00000000":
+        return int(resp.data[:-8]) / 100
